@@ -94,11 +94,11 @@ class Config:
     user_pool_domain = stack["aws_user_pool_domain"]
     self._set(
       "cognito_auth_url",
-      f"https://{user_pool_domain}.auth.{cognito_region}.amazoncognito.com/login",
+      f"https://{user_pool_domain}/login",
     )
     self._set(
       "cognito_token_url",
-      f"https://{user_pool_domain}.auth.{cognito_region}.amazoncognito.com/oauth2/token",
+      f"https://{user_pool_domain}/oauth2/token",
     )
     self._set("api_endpoint", stack["aws_appsync_graphqlEndpoint"])
     self._set("api_region", stack['aws_appsync_region'])
