@@ -5,13 +5,14 @@ class Status:
     self.text = text
 
   def __enter__(self):
-    print(f'thousandwords:{self.text}', end='', file=sys.stderr)
+    print(f'thousandwords:{self.text}', end='')
+    sys.stdout.flush()
     return self
 
   def __exit__(self, exc_type, exc_value, traceback):
     if exc_value is not None:
-      print(' [Failure]', file=sys.stderr)
+      print(' [Failure]')
     else:
-      print(' [Success]', file=sys.stderr)
-    sys.stderr.flush()
+      print(' [Success]')
+    sys.stdout.flush()
     return False
